#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_NEXTPOW2_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_NEXTPOW2_HPP_INCLUDED

#include <boost/simd/ieee/include/functions/scalar/nextpow2.hpp>

#endif
